@@ -95,13 +95,22 @@ class Vdropbox:
 
         return sorted([x.name for x in self.dbx.files_list_folder(folder).entries])
 
+    def mv(self, origin, destination):
+        """ Move a file by copying and deleting """
+
+        self.log.debug(f"Moving file '{origin}' to '{destination}'")
+
+        self.dbx.files_copy(origin, destination)
+        self.dbx.files_delete(origin)
+
     def delete(self, filename):
         """ Delete a file/folder from dropbox """
 
+        self.log.info(f"Deleting '{filename}' from dropbox")
+
         filename = self._check_path(filename)
 
         self.dbx.files_delete(filename)
-        self.log.info(f"File '{filename}' deleted dropbox")
 
     def _raw_read(self, filename):
         """ Auxiliar function for reading from dropbox """
@@ -134,6 +143,8 @@ class Vdropbox:
                 filename:   name of the file
         """
 
+        self.log.info(f"Exporting '{filename}' to dropbox")
+
         if not filename.startswith("/"):
             filename = "/" + filename
 
@@ -146,8 +157,6 @@ class Vdropbox:
             # Write a text file
             self.dbx.files_upload(stream.read(), filename, mode=WriteMode.overwrite)
 
-        self.log.info(f"File '{filename}' exported to dropbox")
-
     def read_yaml(self, filename):
         """
             Read a yaml from dropbox as an ordered dict
@@ -170,6 +179,8 @@ class Vdropbox:
                 filename:   name of the yaml file
         """
 
+        self.log.info(f"Exporting '{filename}' to dropbox")
+
         filename = self._check_path(filename)
 
         with io.StringIO() as stream:
@@ -178,8 +189,6 @@ class Vdropbox:
 
             self.dbx.files_upload(stream.read().encode(), filename, mode=WriteMode.overwrite)
 
-        self.log.info(f"File '{filename}' exported to dropbox")
-
     def read_parquet(self, filename, **kwa):
         """
             Read a parquet from dropbox as a pandas dataframe
@@ -218,6 +227,8 @@ class Vdropbox:
                 **kwa:      keyworded arguments for the pd.to_parquet inner function
         """
 
+        self.log.info(f"Exporting '{filename}' to dropbox")
+
         filename = self._check_path(filename)
 
         with io.BytesIO() as stream:
@@ -226,8 +237,6 @@ class Vdropbox:
 
             self.dbx.files_upload(stream.getvalue(), filename, mode=WriteMode.overwrite)
 
-        self.log.info(f"File '{filename}' exported to dropbox")
-
     def read_excel(self, filename, sheet_names=None, **kwa):
         """
             Read an excel from dropbox as a pandas dataframe
@@ -258,6 +267,8 @@ class Vdropbox:
                 **kwa:      keyworded arguments for the df.to_excel inner function
         """
 
+        self.log.info(f"Exporting '{filename}' to dropbox")
+
         filename = self._check_path(filename)
 
         with io.BytesIO() as stream:
@@ -269,8 +280,6 @@ class Vdropbox:
 
             self.dbx.files_upload(stream.getvalue(), filename, mode=WriteMode.overwrite)
 
-        self.log.info(f"File '{filename}' exported to dropbox")
-
     def read_zip(self, zipfile, file=None, **kwa):
         """
             Reads a zip file in dropbox.
